#!/bin/bash

patch_opt=
if [ $# -eq 2 -a "$1" = "-R" ]; then
  patch_opt=-R
  shift
fi

if [ $# -ne 1 -o ! -d ./$1 ]; then
  echo use: $0 [-R] directory
  exit
fi

export PATH=/bin:/usr/bin:$PATH

rpatch() {
  if [ "$OSTYPE" = "cygwin" ]; then
    dos2unix $1 2>/dev/null
  fi
  patch $patch_opt $1
  if [ "$OSTYPE" = "cygwin" ]; then
    chmod +rw $1
    unix2dos $1 2>/dev/null
  fi
}

echo
echo configure options: -qt-sql-sqlite -no-qt3support -platform win32-msvc2012 -prefix c:Qt4.8.5_64
echo

cd $1

rpatch ./mkspecs/win32-msvc2012/qmake.conf << EOF
19c19
< QMAKE_CFLAGS            = -nologo -Zm200 -Zc:wchar_t-
---
> QMAKE_CFLAGS            = -nologo -Zm200 -Zc:wchar_t- -D_USING_V110_SDK71_
22c22
< QMAKE_CFLAGS_RELEASE    = -O2 -MD
---
> QMAKE_CFLAGS_RELEASE    = -O2 -MD -Zi -Fdvc110r.pdb
59c59
< QMAKE_LFLAGS_RELEASE    = /INCREMENTAL:NO
---
> QMAKE_LFLAGS_RELEASE    = /DEBUG /OPT:REF
62,63c62,63
< QMAKE_LFLAGS_CONSOLE    = /SUBSYSTEM:CONSOLE
< QMAKE_LFLAGS_WINDOWS    = /SUBSYSTEM:WINDOWS
---
> QMAKE_LFLAGS_CONSOLE    = /SUBSYSTEM:CONSOLE,5.02
> QMAKE_LFLAGS_WINDOWS    = /SUBSYSTEM:WINDOWS,5.02
EOF

rpatch ./qmake/generators/win32/msbuild_objectmodel.cpp << EOF
1563a1564,1572
> XmlOutput& xmlPlatformToolSet(XmlOutput& xml)
> {
>     DotNET which_dotnet_version();
>     if (which_dotnet_version() == NET2012) xml << tagValue("PlatformToolSet", "v110_xp");
>     return xml;
> }
> 
> inline XmlOutput& operator<< (XmlOutput& xml, XmlOutput& manip(XmlOutput&)) { return manip(xml); }
> 
1582a1592
>             << xmlPlatformToolSet
1975c1985
<         return "v110";
---
>         return "v110_xp";
EOF

rpatch ./qmake/generators/win32/msvc_vcproj.cpp << EOF
1274c1274,1276
<     vcProject.GeneratedFiles.addFiles(project->values("RES_FILE"));
---
>     if (which_dotnet_version() != NET2012) {
>         vcProject.GeneratedFiles.addFiles(project->values("RES_FILE"));
>     }
EOF

rpatch ./src/3rdparty/webkit/Source/JavaScriptCore/wtf/HashTable.h << EOF
1122,1135d1121
<     template<typename HashTableType, typename ValueType> struct HashTableConstIteratorAdapter {
<         HashTableConstIteratorAdapter() {}
<         HashTableConstIteratorAdapter(const typename HashTableType::const_iterator& impl) : m_impl(impl) {}
< 
<         const ValueType* get() const { return (const ValueType*)m_impl.get(); }
<         const ValueType& operator*() const { return *get(); }
<         const ValueType* operator->() const { return get(); }
< 
<         HashTableConstIteratorAdapter& operator++() { ++m_impl; return *this; }
<         // postfix ++ intentionally omitted
< 
<         typename HashTableType::const_iterator m_impl;
<     };
< 
1147,1150c1133,1136
<         operator HashTableConstIteratorAdapter<HashTableType, ValueType>() {
<             typename HashTableType::const_iterator i = m_impl;
<             return i;
<         }
---
>         //operator HashTableConstIteratorAdapter<HashTableType, ValueType>() {
>         //    typename HashTableType::const_iterator i = m_impl;
>         //    return i;
>         //}
1152a1139,1153
>     };
> 
>     template<typename HashTableType, typename ValueType> struct HashTableConstIteratorAdapter {
>         HashTableConstIteratorAdapter() {}
>         HashTableConstIteratorAdapter(const typename HashTableType::iterator& impl) : m_impl(impl) {}
>         HashTableConstIteratorAdapter(const typename HashTableType::const_iterator& impl) : m_impl(impl) {}
> 
>         const ValueType* get() const { return (const ValueType*)m_impl.get(); }
>         const ValueType& operator*() const { return *get(); }
>         const ValueType* operator->() const { return get(); }
> 
>         HashTableConstIteratorAdapter& operator++() { ++m_impl; return *this; }
>         // postfix ++ intentionally omitted
> 
>         typename HashTableType::const_iterator m_impl;
EOF

rpatch ./src/gui/widgets/qcombobox.cpp << EOF
88a89,100
> bool QComboBox::usePopupStyle() const { return true; }
> 
> namespace
> {
>     inline int styleHint_SH_ComboBox_Popup(const QStyleOption* opt, const QComboBox* combo, const QStyle* style =0)
>     {
>         if (!combo->usePopupStyle()) return 0;
>         if (!style) style = combo->style();
>         return style->styleHint(QStyle::SH_ComboBox_Popup, opt, combo);
>     }
> }
> 
385c397
<     if (combo->style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, combo)) {
---
>     if (styleHint_SH_ComboBox_Popup(&opt, combo)) {
404c416
<     if (combo->style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, combo))
---
>     if (styleHint_SH_ComboBox_Popup(&opt, combo))
432c444
<     const bool usePopup = combo->style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, combo);
---
>     const bool usePopup = styleHint_SH_ComboBox_Popup(&opt, combo);
480c492
<     if (combo->style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, combo) &&
---
>     if (styleHint_SH_ComboBox_Popup(&opt, combo) &&
553c565
<     const bool usePopup = combo->style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, combo);
---
>     const bool usePopup = styleHint_SH_ComboBox_Popup(&opt, combo);
611c623
<     const bool usePopup = combo->style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, combo);
---
>     const bool usePopup = styleHint_SH_ComboBox_Popup(&opt, combo);
630c642
<                                combo->style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, combo));
---
>                                styleHint_SH_ComboBox_Popup(&opt, combo));
1092c1104
<     if (q->style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, q)) {
---
>     if (styleHint_SH_ComboBox_Popup(&opt, q)) {
1666c1678
<     if (q->style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, q)) {
---
>     if (styleHint_SH_ComboBox_Popup(&opt, q)) {
1695c1707
<         if (style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, this)) {
---
>         if (styleHint_SH_ComboBox_Popup(&opt, this)) {
1702c1714
<         if (style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, this)) {
---
>         if (styleHint_SH_ComboBox_Popup(&opt, this)) {
2393c2405
<     const bool usePopup = style->styleHint(QStyle::SH_ComboBox_Popup, &opt, this);
---
>     const bool usePopup = styleHint_SH_ComboBox_Popup(&opt, this, style);
2548c2560
<         && !style->styleHint(QStyle::SH_ComboBox_Popup, &opt, this) && !window()->testAttribute(Qt::WA_DontShowOnScreen))
---
>         && !styleHint_SH_ComboBox_Popup(&opt, this, style) && !window()->testAttribute(Qt::WA_DontShowOnScreen))
2567c2579
<                      style->styleHint(QStyle::SH_ComboBox_Popup, &opt, this)
---
>                      styleHint_SH_ComboBox_Popup(&opt, this, style)
2739c2751
<             if (style()->styleHint(QStyle::SH_ComboBox_Popup, &opt, this)) {
---
>             if (styleHint_SH_ComboBox_Popup(&opt, this))) {
EOF

rpatch ./src/gui/widgets/qcombobox.h << EOF
218a219,220
>     virtual bool usePopupStyle() const;
> 
EOF

rpatch ./src/gui/widgets/qdockarealayout.cpp << EOF
223a224,233
> 
> namespace
> {
>     inline QTabBar::Shape toTabBarShape(int shape)
>     {
>         if (shape < 0) return QTabBar::RoundedNorth;
>         return static_cast<QTabBar::Shape>(shape);
>     }
> }
> 
241c251
<     , tabbed(false), tabBar(0), tabBarShape(static_cast<QTabBar::Shape>(tbshape))
---
>     , tabbed(false), tabBar(0), tabBarShape(tbshape)
646c656,657
<                                         QDockAreaLayoutInfo::TabMode tabMode)
---
>                                         QDockAreaLayoutInfo::TabMode tabMode,
>                                         int& tabPos)
648c659,660
<     if (tabMode == QDockAreaLayoutInfo::ForceTabs)
---
>     if (tabMode == QDockAreaLayoutInfo::ForceTabs) {
>         if (tabPos > 0) tabPos = (tabPos+1) * (_pos.x()-rect.left()) / rect.width();
649a662
>     }
658a672,674
> 
>         if (tabPos > 0) tabPos = (tabPos+1) * (x-w/6) / (2*w/3);
> 
792a809
>     int tabSize = -1;
794a812,822
> #ifndef QT_NO_TABBAR
>     if (item_index < item_list.size()) {
>         const QDockAreaLayoutItem& item = item_list.at(item_index);
>         const QDockAreaLayoutInfo* info = item.subinfo;
>         if (!item.skip() && tabBarShape < 0) {
>             tabSize = (info && info->tabbed && info->tabBar) ? info->tabBar->count() : 1;
>         }
>     }
> #endif
> 
>     int tabPos = tabSize;
796c824
<         = dockPosHelper(item_rect, _pos, o, nestingEnabled, tabMode);
---
>         = dockPosHelper(item_rect, _pos, o, nestingEnabled, tabMode, tabPos);
827a856,873
> #ifndef QT_NO_TABBAR
>             if (tabPos >= 0) {
>                 if (tabPos > tabSize) tabPos = tabSize;
>                 const QDockAreaLayoutItem& item = item_list.at(item_index);
>                 const QDockAreaLayoutInfo* info = item.subinfo;
>                 if (info && info->tabbed && info->tabBar) {
>                     int ng = 0, n = info->item_list.count();
>                     for (int i=0; i<tabPos && i<n; ++i) {
>                         const QDockAreaLayoutItem &item = info->item_list.at(i);
>                         if (item.skip()) ++tabPos;
>                         if (item.flags & QDockAreaLayoutItem::GapItem) ++ng;
>                     }
>                     tabPos -= ng;
>                     if (tabPos > n) tabPos = n;
>                 }
>                 result.last() = tabPos;
>             }
> #endif
1500a1547,1549
>     QRect tab_rect;
>     bool titleBarTabs = false;
> 
1503d1551
<         QRect tab_rect;
1507a1556,1557
>                 case -1:
>                     titleBarTabs = true;
1532c1582,1584
<         widgetAnimator.animate(tabBar, tab_rect, animate);
---
>         if (!titleBarTabs) {
>             widgetAnimator.animate(tabBar, tab_rect, animate);
>         }
1564a1617,1625
>             if (titleBarTabs && dw && r.isValid()) {
>                 int w = tab_rect.width();
>                 QDockWidgetLayout* layout = qobject_cast<QDockWidgetLayout*>(dw->layout());
>                 QWidget* cw = layout ? layout->widgetForRole(QDockWidgetLayout::CloseButton) : 0;
>                 if (cw && cw->isVisible()) w = qMin(cw->geometry().left(), w);
>                 QWidget* fw = layout ? layout->widgetForRole(QDockWidgetLayout::FloatButton) : 0;
>                 if (fw && fw->isVisible()) w = qMin(fw->geometry().left(), w);
>                 tab_rect.setWidth(w);
>             }
1566a1628,1630
>     if (titleBarTabs) {
>         widgetAnimator.animate(tabBar, tab_rect, animate);
>     }
1679c1743
<         item_list.append(QDockAreaLayoutItem(dockWidgetItem));
---
>         item_list.insert(index+1, QDockAreaLayoutItem(dockWidgetItem));
2095,2096c2159,2160
<         that->tabBar->setShape(static_cast<QTabBar::Shape>(tabBarShape));
<         that->tabBar->setDrawBase(true);
---
>         that->tabBar->setShape(toTabBarShape(tabBarShape));
>         that->tabBar->setDrawBase(tabBarShape >= 0);
2109c2173
<             continue;
---
>             if (tabBarShape >= 0) continue;
2150a2215
>     tabBar->raise();
2161,2162c2226,2229
<     if (tabBar != 0)
<         tabBar->setShape(static_cast<QTabBar::Shape>(shape));
---
>     if (tabBar != 0) {
>         tabBar->setShape(toTabBarShape(shape));
>         tabBar->setDrawBase(tabBarShape >= 0);
>     }
2202a2270,2290
> }
> 
> bool QDockAreaLayoutInfo::tabBarDockDrag(const QPoint& globalPos, const QTabBar* bar)
> {
>     if (!tabbed || tabBar != bar || tabBarShape >= 0) return false;
> 
>     quintptr currTabId = currentTabId();
>     if (currTabId == 0) return false;
> 
> 
>     int n = item_list.count();
>     for (int i=0; i<n; ++i) {
>         const QDockAreaLayoutItem& item = item_list.at(i);
>         if (tabId(item) == currTabId) {
>             if (!item.widgetItem) return false;
>             QDockWidget* dock = qobject_cast<QDockWidget*>(item.widgetItem->widget());
>             if (!dock) return false;
>             return dock->tabBarDockDrag(globalPos);
>         }
>     }
>     return false;
EOF

rpatch ./src/gui/widgets/qdockarealayout_p.h << EOF
219a220,221
> 
>     bool tabBarDockDrag(const QPoint&, const QTabBar*);
EOF

rpatch ./src/gui/widgets/qdockwidget.cpp << EOF
459a460
>     int h = qMax(buttonHeight + 2, titleFontMetrics.lineSpacing() + 2*mw);
461c462,471
<     return qMax(buttonHeight + 2, titleFontMetrics.height() + 2*mw);
---
> #ifndef QT_NO_TABBAR
>     QMainWindow* win = qobject_cast<QMainWindow*>(q->parentWidget());
>     QMainWindowLayout* winLayout = win ? qobject_cast<QMainWindowLayout*>(win->layout()) : 0;
>     QDockAreaLayoutInfo* info = winLayout ? winLayout->layoutState.dockAreaLayout.info(q) : 0;
>     QSize tbSize = (info && info->tabBarShape < 0) ? info->tabBarSizeHint() : QSize();
>     int tbh = tbSize.height();
>     if (tbh > h) h = tbh;
> #endif // QT_NO_TABBAR
> 
>     return h;
639a650,655
> bool QDockWidget::tabBarDockDrag(const QPoint& globalPos)
> {
>     Q_D(QDockWidget);
>     return d->tabBarDockDrag(globalPos);
> }
> 
688c704
< void QDockWidgetPrivate::initDrag(const QPoint &pos, bool nca)
---
> void QDockWidgetPrivate::initDrag(const QPoint &pos, bool nca, bool bar)
700a717,725
> #ifdef QT_NO_TABBAR
>     Q_UNUSED(bar)
> #else
>     if (!bar) {
>         QDockAreaLayoutInfo* info = layout->layoutState.dockAreaLayout.info(q);
>         if (info && info->tabbed && info->tabBar && info->tabBarShape < 0) return;
>     }
> #endif // QT_NO_TABBAR
> 
741a767,769
>         state->ctrlDrag = ::hasFeature(q, QDockWidget::DockWidgetFloatable);
> 
>     if (state->ctrlDrag)
801a830,859
> bool QDockWidgetPrivate::tabBarDockDrag(const QPoint& globalPos)
> {
>     Q_Q(QDockWidget);
>     if (state) return false;
>     if (!(QApplication::mouseButtons() &  Qt::LeftButton)) return false;
>     QPoint pos = q->mapFromGlobal(globalPos);
>     initDrag(pos, false, true);
>     if (!state) return false;
>     startDrag();
>     q->grabMouse();
>     return true;
> }
> 
> void QDockWidgetPrivate::hover(QMainWindowLayout* layout, const QPoint& pos)
> {
>     if (!layout || state->ctrlDrag) return;
>     layout->hover(state->widgetItem, pos);
> 
> #ifndef QT_NO_TABBAR
>     Q_Q(QDockWidget);
> 
>     QDockAreaLayoutInfo* info = layout->layoutState.dockAreaLayout.info(q);
>     if (!info || !info->tabbed || !info->tabBar || info->tabBarShape >= 0) return;
> 
>     info->updateTabBar();
>     info->setCurrentTab(q);
>     info->tabBar->show();
> #endif // QT_NO_TABBAR
> }
> 
823c881
<         initDrag(event->pos(), false);
---
>         initDrag(event->pos(), false, false);
881,884c939
< 
<         if (!state->ctrlDrag)
<             mwlayout->hover(state->widgetItem, event->globalPos());
< 
---
>         hover(mwlayout, event->globalPos());
937c992
<             initDrag(event->pos(), true);
---
>             initDrag(event->pos(), true, false);
960,962c1015
<                 if (!state->ctrlDrag)
<                     layout->hover(state->widgetItem, event->globalPos());
<             }
---
>                 hover(layout, event->globalPos());
EOF

rpatch ./src/gui/widgets/qdockwidget.h << EOF
135a136,137
> 
>     bool tabBarDockDrag(const QPoint& globalPos);
EOF

rpatch ./src/gui/widgets/qdockwidget_p.h << EOF
70a71
> class QMainWindowLayout;
120c121
<     void initDrag(const QPoint &pos, bool nca);
---
>     void initDrag(const QPoint &pos, bool nca, bool bar);
128a130,132
> 
>     bool tabBarDockDrag(const QPoint& globalPos);
>     void hover(QMainWindowLayout*, const QPoint&);
EOF

rpatch ./src/gui/widgets/qmainwindow.h << EOF
92c92,93
<         VerticalTabs = 0x10       // implies AllowTabbedDocks
---
>         VerticalTabs = 0x10,      // implies AllowTabbedDocks
>         TitleBarTabs = 0x20
EOF

rpatch ./src/gui/widgets/qmainwindowlayout.cpp << EOF
835a836,846
> void QMainWindowLayout::setTitleBarTabsEnabled()
> {
> #ifndef QT_NO_TABBAR
>     QDockAreaLayout &layout = layoutState.dockAreaLayout;
> 
>     for (int i = 0; i < QInternal::DockCount; ++i) {
>         layout.docks[i].setTabBarShape(-1);
>     }
> #endif // QT_NO_TABBAR
> }
> 
1272a1284,1294
> 
> private:
>     int draggingIdx;
> 
>     QPoint pos, globalPos;
>     Qt::MouseButtons buttons;
>     Qt::KeyboardModifiers modifiers;
> 
>     virtual void mousePressEvent(QMouseEvent*);
>     virtual void mouseMoveEvent(QMouseEvent*);
>     virtual void mouseReleaseEvent(QMouseEvent*);
1278a1301
>     draggingIdx = -1;
1298a1322,1366
> void QMainWindowTabBar::mousePressEvent(QMouseEvent* e)
> {
>     if (e->button() == Qt::LeftButton)  {
>         int idx = tabAt(e->pos());
>         if (idx >= 0 && idx == currentIndex()) {
>             draggingIdx = idx;
>             pos = e->pos();
>             globalPos = e->globalPos();
>             modifiers = e->modifiers();
>             buttons = e->buttons();
>             return;
>         }
>     }
>     draggingIdx = -1;
>     QTabBar::mousePressEvent(e);
> }
> 
> void QMainWindowTabBar::mouseReleaseEvent(QMouseEvent* e)
> {
>     if (draggingIdx >= 0) {
>         QMouseEvent ev(QEvent::MouseButtonPress, pos, globalPos, Qt::LeftButton, buttons, modifiers); 
>         QTabBar::mousePressEvent(&ev);
>         draggingIdx = -1;
>     }
>     QTabBar::mouseReleaseEvent(e);
> }
> 
> void QMainWindowTabBar::mouseMoveEvent(QMouseEvent* e)
> {
>     if (draggingIdx >= 0) {
>         bool drag = (draggingIdx == currentIndex());
>         if (drag && (e->pos() - pos).manhattanLength() <= QApplication::startDragDistance()) return;
>         draggingIdx = -1;
>         if (drag) {
>             QWidget* main = parentWidget();
>             QMainWindowLayout* layout = main ? qobject_cast<QMainWindowLayout*>(main->layout()) : 0;
>             QDockAreaLayoutInfo* area = layout ? layout->layoutState.dockAreaLayout.info(this) : 0;
>             if (area && area->tabBarDockDrag(globalPos, this)) return;
>         }
>         QMouseEvent ev(QEvent::MouseButtonPress, pos, globalPos, Qt::LeftButton, buttons, modifiers); 
>         QTabBar::mousePressEvent(&ev);
>     }
>     QTabBar::mouseMoveEvent(e);
> }
> 
1751c1819,1824
<     setVerticalTabsEnabled(opts & QMainWindow::VerticalTabs);
---
>     if (opts & QMainWindow::TitleBarTabs) {
>         setTitleBarTabsEnabled();
>     }
>     else {
>         setVerticalTabsEnabled(opts & QMainWindow::VerticalTabs);
>     }
EOF

rpatch ./src/gui/widgets/qmainwindowlayout_p.h << EOF
203a204
>     void setTitleBarTabsEnabled();
EOF

rpatch ./src/gui/widgets/qsizegrip.cpp << EOF
92a93
>     bool noWinMgr;
242a244
>     noWinMgr = false;
311c313
<     if (tlw->isWindow() && X11->isSupportedByWM(ATOM(_NET_WM_MOVERESIZE))
---
>     if (!d->noWinMgr && tlw->isWindow() && X11->isSupportedByWM(ATOM(_NET_WM_MOVERESIZE))
335c337
<     if (tlw->isWindow() && !tlw->testAttribute(Qt::WA_DontShowOnScreen) && !qt_widget_private(tlw)->hasHeightForWidth()) {
---
>     if (!d->noWinMgr && tlw->isWindow() && !tlw->testAttribute(Qt::WA_DontShowOnScreen) && !qt_widget_private(tlw)->hasHeightForWidth()) {
423c425
<     if (tlw->isWindow() && X11->isSupportedByWM(ATOM(_NET_WM_MOVERESIZE))
---
>     if (!d->noWinMgr && tlw->isWindow() && X11->isSupportedByWM(ATOM(_NET_WM_MOVERESIZE))
429c431
<     if (tlw->isWindow() && GetSystemMenu(tlw->winId(), FALSE) != 0 && internalWinId()
---
>     if (!d->noWinMgr && tlw->isWindow() && GetSystemMenu(tlw->winId(), FALSE) != 0 && internalWinId()
528a531,536
> }
> 
> void QSizeGrip::setNoWinMgr(bool noWinMgr)
> {
>     Q_D(QSizeGrip);
>     d->noWinMgr = noWinMgr;
EOF

rpatch ./src/gui/widgets/qsizegrip.h << EOF
63a64
>     void setNoWinMgr(bool);
EOF

rpatch ./tools/assistant/tools/assistant/mainwindow.cpp << EOF
109c109
<     setDockOptions(dockOptions() | AllowNestedDocks);
---
>     setDockOptions(dockOptions() | TitleBarTabs);
EOF

rpatch ./tools/linguist/lupdate/cpp.cpp << EOF
817a818,819
>                     int k = 0;
>                     const char* skip = "TR_CLASS";
822a825,828
>                         if (k >= 0) {
>                             k = (yyCh == skip[k]) ? k+1 : (k == 0 && yyCh == ' ') ? 0 : -1;
>                             if (k >= 0 && !skip[k]) break;
>                         }
EOF

rpatch ./src/3rdparty/clucene/src/CLucene/queryParser/QueryParserBase.cpp << EOF
259a260,262
>   if ((terms[0] == NULL) || (terms[1] == NULL)) {
>     _CLTHROWA(CL_ERR_Parse, "No range given.");
>   }
EOF

rpatch ./src/gui/kernel/qwidget_win.cpp << EOF
1310c1310
<     bool jump = (data.wrect != wrect);
---
>     bool jump = true;//(data.wrect != wrect);
EOF

rpatch ./tools/assistant/lib/qhelpsearchindexwriter_clucene.cpp << EOF
735c735,736
<         writer->setMaxFieldLength(QCLuceneIndexWriter::DEFAULT_MAX_FIELD_LENGTH);
---
>         //writer->setMaxFieldLength(QCLuceneIndexWriter::DEFAULT_MAX_FIELD_LENGTH);
>         writer->setMaxFieldLength(0x7fffffff);
EOF

cd ..
